@@ -8,6 +8,8 @@ from datetime import timedelta
 
 import pytest
 
+from tests.util import assert_is_ppo
+from tests.util import elementary_test
 from tomlkit import api
 from tomlkit import parse
 from tomlkit.exceptions import NonExistentKey
@@ -27,9 +29,6 @@ from tomlkit.items import Trivia
 from tomlkit.items import item
 from tomlkit.parser import Parser
 
-from .util import assert_is_ppo
-from .util import elementary_test
-
 
 @pytest.fixture()
 def tz_pst():
@@ -120,7 +119,7 @@ def test_aot_unwrap():
     d = item([{"a": "A"}, {"b": "B"}])
     unwrapped = d.unwrap()
     assert_is_ppo(unwrapped, list)
-    for du, dw in zip(unwrapped, d):
+    for du, _ in zip(unwrapped, d):
         assert_is_ppo(du, dict)
         for ku in du:
             vu = du[ku]
@@ -182,26 +181,26 @@ def test_items_can_be_appended_to_and_removed_from_a_table():
     _, table = parser._parse_table()
 
     assert isinstance(table, Table)
-    assert "" == table.as_string()
+    assert table.as_string() == ""
 
     table.append(Key("foo"), String(StringType.SLB, "bar", "bar", Trivia(trail="\n")))
 
-    assert 'foo = "bar"\n' == table.as_string()
+    assert table.as_string() == 'foo = "bar"\n'
 
     table.append(
         Key("baz"),
         Integer(34, Trivia(comment_ws="   ", comment="# Integer", trail=""), "34"),
     )
 
-    assert 'foo = "bar"\nbaz = 34   # Integer' == table.as_string()
+    assert table.as_string() == 'foo = "bar"\nbaz = 34   # Integer'
 
     table.remove(Key("baz"))
 
-    assert 'foo = "bar"\n' == table.as_string()
+    assert table.as_string() == 'foo = "bar"\n'
 
     table.remove(Key("foo"))
 
-    assert "" == table.as_string()
+    assert table.as_string() == ""
 
     with pytest.raises(NonExistentKey):
         table.remove(Key("foo"))
@@ -215,23 +214,23 @@ def test_items_can_be_appended_to_and_removed_from_an_inline_table():
     _, table = parser._parse_item()
 
     assert isinstance(table, InlineTable)
-    assert "{}" == table.as_string()
+    assert table.as_string() == "{}"
 
     table.append(Key("foo"), String(StringType.SLB, "bar", "bar", Trivia(trail="")))
 
-    assert '{foo = "bar"}' == table.as_string()
+    assert table.as_string() == '{foo = "bar"}'
 
     table.append(Key("baz"), Integer(34, Trivia(trail=""), "34"))
 
-    assert '{foo = "bar", baz = 34}' == table.as_string()
+    assert table.as_string() == '{foo = "bar", baz = 34}'
 
     table.remove(Key("baz"))
 
-    assert '{foo = "bar"}' == table.as_string()
+    assert table.as_string() == '{foo = "bar"}'
 
     table.remove(Key("foo"))
 
-    assert "{}" == table.as_string()
+    assert table.as_string() == "{}"
 
     with pytest.raises(NonExistentKey):
         table.remove(Key("foo"))
@@ -339,7 +338,7 @@ def test_array_multiline():
     t = item([])
     t.multiline(True)
 
-    assert "[]" == t.as_string()
+    assert t.as_string() == "[]"
 
 
 def test_array_multiline_modify():
@@ -369,7 +368,7 @@ a = [
 def test_append_to_empty_array():
     doc = parse("x = [ ]")
     doc["x"].append("a")
-    assert doc.as_string() == 'x = [ "a" ]'
+    assert doc.as_string() == 'x = ["a" ]'
     doc = parse("x = [\n]")
     doc["x"].append("a")
     assert doc.as_string() == 'x = [\n    "a"\n]'
@@ -411,6 +410,8 @@ x = [
     2
 ]"""
     )
+    doc["x"].pop(0)
+    assert doc.as_string() == "x = [\n    2\n]"
 
 
 def test_append_to_multiline_array_with_comment():
@@ -433,14 +434,25 @@ x = [
     2,
     3,
 ]
+"""
+    )
+    assert doc["x"].pop() == 3
+    assert (
+        doc.as_string()
+        == """\
+x = [
+    # Here is a comment
+    1,
+    2,
+]
 """
     )
 
 
 def test_append_dict_to_array():
-    doc = parse("x = [ ]")
+    doc = parse("x = []")
     doc["x"].append({"name": "John Doe", "email": "john@doe.com"})
-    expected = 'x = [ {name = "John Doe",email = "john@doe.com"} ]'
+    expected = 'x = [{name = "John Doe",email = "john@doe.com"}]'
     assert doc.as_string() == expected
     # Make sure the produced string is valid
     assert parse(doc.as_string()) == doc
@@ -470,7 +482,7 @@ def test_array_add_line():
         == """[
     1, 2, 3, # Line 1
     4, 5, 6, # Line 2
-    7, 8
+    7, 8,
 ]"""
     )
 
@@ -563,6 +575,13 @@ bar = "baz"
     )
 
 
+def test_add_sum_int_with_float():
+    content = "[table]\nmy_int = 2048.3"
+    doc = parse(content)
+    doc["table"]["my_int"] += 5
+    assert doc["table"]["my_int"] == 2053.3
+
+
 def test_integers_behave_like_ints():
     i = item(34)
 
@@ -791,7 +810,7 @@ def test_trim_comments_when_building_inline_table():
     value.comment("Another comment")
     table.append("baz", value)
     assert "# Another comment" not in table.as_string()
-    assert '{foo = "bar", baz = "foobaz"}' == table.as_string()
+    assert table.as_string() == '{foo = "bar", baz = "foobaz"}'
 
 
 def test_deleting_inline_table_elemeent_does_not_leave_trailing_separator():
@@ -799,11 +818,11 @@ def test_deleting_inline_table_elemeent_does_not_leave_trailing_separator():
     table["foo"] = "bar"
     table["baz"] = "boom"
 
-    assert '{foo = "bar", baz = "boom"}' == table.as_string()
+    assert table.as_string() == '{foo = "bar", baz = "boom"}'
 
     del table["baz"]
 
-    assert '{foo = "bar"}' == table.as_string()
+    assert table.as_string() == '{foo = "bar"}'
 
     table = api.inline_table()
     table["foo"] = "bar"
@@ -812,7 +831,7 @@ def test_deleting_inline_table_elemeent_does_not_leave_trailing_separator():
 
     table["baz"] = "boom"
 
-    assert '{baz = "boom"}' == table.as_string()
+    assert table.as_string() == '{baz = "boom"}'
 
 
 def test_booleans_comparison():
